import * as cdk from 'aws-cdk-lib';
import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
export interface WorkSpaceBucketProps {
    /**
               * The bucket name for the workspace of an EMR Studio.
               *
               * @default - 'emr-studio-workspace-bucket-AWS::AccountId'
               */
    readonly bucketName?: string;
    /**
               * Policy to apply when the bucket is removed from this stack.
               *
               * @default - The bucket will be deleted.
               */
    readonly removalPolicy?: cdk.RemovalPolicy;
}
export declare class WorkSpaceBucket extends Construct {
    readonly bucketEntity: s3.Bucket;
    constructor(scope: Construct, name: string, props?: WorkSpaceBucketProps);
}
/**
 * Properties for the EMR Serverless bucket.
 */
export interface EmrServerlessBucketProps {
    /**
               * The bucket name for EMR Serverless applications.
               *
               * @default - 'emr-serverless-AWS::AccountId'
               */
    readonly bucketName?: string;
    /**
               * Policy to apply when the bucket is removed from this stack.
               *
               * @default - The bucket will be deleted.
               */
    readonly removalPolicy?: cdk.RemovalPolicy;
}
/**
 * Creates a bucket for EMR Serverless applications.
 *
 * ```ts
 * const emrServerlessBucket = new EmrServerlessBucket(this, 'EmrServerless');
 * ```
 */
export declare class EmrServerlessBucket extends Construct {
    readonly bucketEntity: s3.Bucket;
    constructor(scope: Construct, name: string, props?: EmrServerlessBucketProps);
}
